@@ -6,19 +6,7 @@ from typing import Tuple, Dict
 from dataclasses import dataclass
 import logging
 
-# Set up logger (optional - only if logging is enabled)
 _logger = logging.getLogger(__name__)
-if not _logger.handlers:
-    # Only configure if logging is enabled (avoid overhead if disabled)
-    root_logger = logging.getLogger()
-    if root_logger.level <= logging.WARNING:
-        _logger.setLevel(logging.WARNING)
-        handler = logging.StreamHandler()
-        handler.setFormatter(logging.Formatter(
-            '%(asctime)s - %(name)s - %(levelname)s - %(message)s',
-            datefmt='%Y-%m-%d %H:%M:%S'
-        ))
-        _logger.addHandler(handler)
 
 
 @dataclass
@@ -324,9 +312,13 @@ def skf(Y: np.ndarray, A: np.ndarray, C: np.ndarray, Q: np.ndarray,
         VmU[:, :, t + 1] = Vu
     
     # Store Kalman gain k_t (from final iteration)
+    # k_t should be m x n_obs where n_obs is number of observed series at final time
+    # VCF is m x n_obs, C_t is n_obs x m, so VCF @ C_t gives m x m
+    # However, if no observations at final time, use zeros
     if len(Y_t) == 0:
         k_t = np.zeros((m, m))
     else:
+        # VCF is m x n_obs, C_t is n_obs x m, so k_t = VCF @ C_t is m x m
         k_t = VCF @ C_t
     
     return KalmanFilterState(Zm=Zm, Vm=Vm, ZmU=ZmU, VmU=VmU, loglik=loglik, k_t=k_t)
