@@ -11,7 +11,7 @@ import pytest
 project_root = Path(__file__).parent.parent.parent
 sys.path.insert(0, str(project_root / 'src'))
 
-from dfm_python.dfm import dfm, DFMResult, em_step, init_conditions
+from dfm_python.dfm import DFM, DFMResult, em_step, init_conditions
 from dfm_python.data_loader import load_config, load_data
 from dfm_python.utils.data_utils import rem_nans_spline
 from dfm_python.config import DFMConfig, SeriesConfig, BlockConfig
@@ -103,7 +103,7 @@ def test_dfm_quick():
     X[missing_mask] = np.nan
     
     # Create config (single global block)
-    blocks = {'Block_Global': BlockConfig(factors=1, ar_lag=1, load_on_global=False, clock='m')}
+    blocks = {'Block_Global': BlockConfig(factors=1, ar_lag=1, clock='m')}
     series_list = []
     for i in range(N):
         series_list.append(SeriesConfig(
@@ -116,7 +116,8 @@ def test_dfm_quick():
     config = DFMConfig(series=series_list, blocks=blocks)
     
     # Run DFM
-    Res = dfm(X, config, threshold=1e-2, max_iter=5)
+    model = DFM()
+    Res = model.fit(X, config, threshold=1e-2, max_iter=5)
     
     # Verify structure
     assert hasattr(Res, 'x_sm') and hasattr(Res, 'X_sm')
@@ -127,6 +128,41 @@ def test_dfm_quick():
     assert np.any(np.isfinite(Res.Z))
 
 
+def test_dfm_class_fit():
+    """Test DFM class fit() method (new API)."""
+    np.random.seed(42)
+    T, N = 50, 5
+    
+    X = np.random.randn(T, N)
+    
+    # Create config
+    blocks = {'Block_Global': BlockConfig(factors=1, ar_lag=1, clock='m')}
+    series_list = []
+    for i in range(N):
+        series_list.append(SeriesConfig(
+            series_id=f"TEST_{i:02d}",
+            frequency='m',
+            transformation='lin',
+            blocks=['Block_Global']
+        ))
+    config = DFMConfig(series=series_list, blocks=blocks)
+    
+    # Use DFM class directly
+    model = DFM()
+    result = model.fit(X, config, threshold=1e-2, max_iter=5)
+    
+    # Verify structure
+    assert isinstance(result, DFMResult)
+    assert result.x_sm.shape == (T, N)
+    assert result.Z.shape[0] == T
+    assert result.C.shape[0] == N
+    assert np.any(np.isfinite(result.Z))
+    
+    # Verify model stores result
+    assert model.result is not None
+    assert model.config is not None
+
+
 def test_multi_block_different_factors():
     """Test multi-block with different factor counts."""
     np.random.seed(42)
@@ -168,7 +204,7 @@ def test_single_series():
     np.random.seed(42)
     X = np.random.randn(T, 1)
     
-    blocks = {'Block_Global': BlockConfig(factors=1, ar_lag=1, load_on_global=False, clock='m')}
+    blocks = {'Block_Global': BlockConfig(factors=1, ar_lag=1, clock='m')}
     series_list = [SeriesConfig(
         series_id="TEST_01",
         series_name="Test Series",
@@ -178,7 +214,8 @@ def test_single_series():
     )]
     config = DFMConfig(series=series_list, blocks=blocks)
     
-    Res = dfm(X, config, threshold=1e-2, max_iter=5)
+    model = DFM()
+    Res = model.fit(X, config, threshold=1e-2, max_iter=5)
     
     assert Res.x_sm.shape == (T, 1)
     assert Res.Z.shape[0] == T
@@ -190,7 +227,7 @@ def test_all_nan_data():
     T, N = 50, 5
     X = np.full((T, N), np.nan)
     
-    blocks = {'Block_Global': BlockConfig(factors=1, ar_lag=1, load_on_global=False, clock='m')}
+    blocks = {'Block_Global': BlockConfig(factors=1, ar_lag=1, clock='m')}
     series_list = []
     for i in range(N):
         series_list.append(SeriesConfig(
@@ -206,7 +243,8 @@ def test_all_nan_data():
     with warnings.catch_warnings():
         warnings.simplefilter("ignore")
         try:
-            Res = dfm(X, config, threshold=1e-2, max_iter=5)
+            model = DFM()
+            Res = model.fit(X, config, threshold=1e-2, max_iter=5)
             assert Res.x_sm.shape == (T, N)
         except (ValueError, RuntimeError) as e:
             # Acceptable - all NaN data is invalid
@@ -223,7 +261,7 @@ def test_high_missing_data():
     missing_mask = np.random.rand(T, N) < 0.8
     X[missing_mask] = np.nan
     
-    blocks = {'Block_Global': BlockConfig(factors=1, ar_lag=1, load_on_global=False, clock='m')}
+    blocks = {'Block_Global': BlockConfig(factors=1, ar_lag=1, clock='m')}
     series_list = []
     for i in range(N):
         series_list.append(SeriesConfig(
@@ -237,7 +275,8 @@ def test_high_missing_data():
     
     with warnings.catch_warnings():
         warnings.simplefilter("ignore")
-        Res = dfm(X, config, threshold=1e-2, max_iter=5)
+        model = DFM()
+        Res = model.fit(X, config, threshold=1e-2, max_iter=5)
         
         assert Res.x_sm.shape == (T, N)
         assert np.any(np.isfinite(Res.Z))
@@ -249,7 +288,7 @@ def test_mixed_frequencies():
     np.random.seed(42)
     X = np.random.randn(T, N)
     
-    blocks = {'Block_Global': BlockConfig(factors=1, ar_lag=1, load_on_global=False, clock='m')}
+    blocks = {'Block_Global': BlockConfig(factors=1, ar_lag=1, clock='m')}
     series_list = []
     for i in range(N):
         freq = 'm' if i < 5 else 'q'
@@ -264,7 +303,8 @@ def test_mixed_frequencies():
     
     with warnings.catch_warnings():
         warnings.simplefilter("ignore")
-        Res = dfm(X, config, threshold=1e-2, max_iter=5)
+        model = DFM()
+        Res = model.fit(X, config, threshold=1e-2, max_iter=5)
         
         assert Res.x_sm.shape == (T, N)
         assert np.any(np.isfinite(Res.Z))
@@ -280,7 +320,7 @@ def test_large_dataset():
     np.random.seed(42)
     X = np.random.randn(T, N)
     
-    blocks = {'Block_Global': BlockConfig(factors=1, ar_lag=1, load_on_global=False, clock='m')}
+    blocks = {'Block_Global': BlockConfig(factors=1, ar_lag=1, clock='m')}
     series_list = []
     for i in range(N):
         series_list.append(SeriesConfig(
@@ -292,7 +332,8 @@ def test_large_dataset():
         ))
     config = DFMConfig(series=series_list, blocks=blocks)
     
-    Res = dfm(X, config, threshold=1e-2, max_iter=20)
+    model = DFM()
+    Res = model.fit(X, config, threshold=1e-2, max_iter=20)
     
     assert Res.x_sm.shape == (T, N)
     assert Res.Z.shape[0] == T
@@ -305,7 +346,7 @@ def test_numerical_precision():
     np.random.seed(42)
     X = np.random.randn(T, N) * 1e-10
     
-    blocks = {'Block_Global': BlockConfig(factors=1, ar_lag=1, load_on_global=False, clock='m')}
+    blocks = {'Block_Global': BlockConfig(factors=1, ar_lag=1, clock='m')}
     series_list = []
     for i in range(N):
         series_list.append(SeriesConfig(
@@ -319,7 +360,8 @@ def test_numerical_precision():
     
     with warnings.catch_warnings():
         warnings.simplefilter("ignore")
-        Res = dfm(X, config, threshold=1e-3, max_iter=50)
+        model = DFM()
+        Res = model.fit(X, config, threshold=1e-3, max_iter=50)
         
         assert Res.x_sm.shape == (T, N)
         assert np.all(np.isfinite(Res.Z))
@@ -349,7 +391,7 @@ def test_with_direct_config():
             )
         ]
         
-        blocks = {'Block_Global': BlockConfig(factors=1, ar_lag=1, load_on_global=False, clock='m')}
+        blocks = {'Block_Global': BlockConfig(factors=1, ar_lag=1, clock='m')}
         config = DFMConfig(series=series_list, blocks=blocks)
         
         # Generate simple synthetic data
@@ -357,7 +399,8 @@ def test_with_direct_config():
         np.random.seed(42)
         X = np.random.randn(T, 2)
         
-        result = dfm(X, config, threshold=1e-2, max_iter=5)
+        model = DFM()
+        result = model.fit(X, config, threshold=1e-2, max_iter=5)
         
         assert result.Z.shape[1] > 0
         assert result.C.shape[0] == 2
