@@ -47,7 +47,8 @@ def test_update_nowcast_basic():
         # Quick DFM estimation for testing
         with warnings.catch_warnings():
             warnings.simplefilter("ignore")
-            Res = dfm(X_old, config, threshold=1e-3, max_iter=20)
+            model = DFM()
+            Res = model.fit(X_old, config, threshold=1e-3, max_iter=20)
         
         update_nowcast(X_old, X_new, Time, config, Res, 
                       series='GDPC1', period='2016q4',
